diff --git a/docker-compose.yml b/docker-compose.yml
index 8a04c883c435e00267270158324d85098ecb1c8b..688177c2cddff8f8083dc6ce2a208ed6819905b7 100644
--- a/docker-compose.yml
+++ b/docker-compose.yml
@@ -173,7 +173,7 @@ services:
   vault:
     hostname: vault
     container_name: vault
-    image: vault:1.10.3
+    image: vault:1.12.0
     environment:
       VAULT_ADDR: "http://0.0.0.0:8200"
       VAULT_API_ADDR: "http://0.0.0.0:8200"
@@ -188,7 +188,7 @@ services:
 
   vault-init:
     container_name: vault-init
-    image: vault:1.10.3
+    image: vault:1.12.0
     volumes:
       - ./vault/vault-init.sh:/vault-init.sh
     depends_on:
diff --git a/mongo/docker-entrypoint-initdb.d/mongo-init.js b/mongo/docker-entrypoint-initdb.d/mongo-init.js
index 106b533c5788e9b1fbee42b644a689ce883af18d..32c1efb1b01b8f9ddfdb2885702b61f4eb36f825 100644
--- a/mongo/docker-entrypoint-initdb.d/mongo-init.js
+++ b/mongo/docker-entrypoint-initdb.d/mongo-init.js
@@ -135,12 +135,15 @@ db.exports.insertMany(
     [
         {
             "exportName":"testexport",
-            "contexts":["https://www.w3.org/2018/credentials/examples/v1"],
+            "contexts":["https://w3id.org/security/suites/jws-2020/v1"],
             "policies":{
                 "example/example/1.0":{},
                 "example/example/2.0":{"hello":"world"}
             },
-            "cacheTTL": 300
+            "cacheTTL": 300,
+            "key": "key1",
+            "keyNamespace": "transit",
+            "issuer": "did:web:example.com"
         }
     ]
 );
diff --git a/nginx/nginx.conf b/nginx/nginx.conf
index fd4d514606c8ce20edbadb7e311969cf678c2b28..89e8617d6317438756df2f38a2875ec506fa2ba3 100644
--- a/nginx/nginx.conf
+++ b/nginx/nginx.conf
@@ -15,6 +15,7 @@ http {
         }
 
         location /policy/ {
+            proxy_pass_request_headers on;
             proxy_pass http://policy:8080/;
         }
 
diff --git a/vault/vault-init.sh b/vault/vault-init.sh
index 529885cd3c80227b7da10c578edd11e8f042df07..5871bf3f3df46f0d698d5cb8fd3bec7d112e9d26 100755
--- a/vault/vault-init.sh
+++ b/vault/vault-init.sh
@@ -12,8 +12,11 @@ vault login root
 # enable vault transit engine
 vault secrets enable transit
 
-# create key1 with type ed25519
-vault write -f transit/keys/key1 type=ed25519
+# create key1 with type ecdsa-p256
+vault write -f transit/keys/key1 type=ecdsa-p256
 
-# create key2 with type ecdsa-p256
-vault write -f transit/keys/key2 type=ecdsa-p256
+# create key2 with type ed25519
+vault write -f transit/keys/key2 type=ed25519
+
+# create key3 with type rsa4096
+vault write -f transit/keys/key3 type=rsa4096